aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMartijn Kaijser <martijn@xbmc.org>2018-12-16 10:17:20 +0100
committerGitHub <noreply@github.com>2018-12-16 10:17:20 +0100
commit5c2ecda3176f1491f6875045583f6cd1c90c7914 (patch)
treec612fae2d1153cbb89990ad62711e73da7a2d12b
parent0bbeefdadbc243a39d3f73124278d37e060836b7 (diff)
parentdba8747c677580ad32cadf1633be0c4f093cc579 (diff)
Merge pull request #15047 from samnazarko/fix_aml_contrast
AMLCodec: fix contrast setting
-rw-r--r--xbmc/cores/VideoPlayer/DVDCodecs/Video/AMLCodec.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/xbmc/cores/VideoPlayer/DVDCodecs/Video/AMLCodec.cpp b/xbmc/cores/VideoPlayer/DVDCodecs/Video/AMLCodec.cpp
index 348a1dc1bb..82bf70596b 100644
--- a/xbmc/cores/VideoPlayer/DVDCodecs/Video/AMLCodec.cpp
+++ b/xbmc/cores/VideoPlayer/DVDCodecs/Video/AMLCodec.cpp
@@ -2206,8 +2206,8 @@ void CAMLCodec::SetVideoZoom(const float zoom)
void CAMLCodec::SetVideoContrast(const int contrast)
{
// input contrast range is 0 to 100 with default of 50.
- // output contrast range is -255 to 255 with default of 0.
- int aml_contrast = (255 * (contrast - 50)) / 50;
+ // output contrast range is -127 to 127 with default of 0.
+ int aml_contrast = (127 * (contrast - 50)) / 50;
SysfsUtils::SetInt("/sys/class/video/contrast", aml_contrast);
}
void CAMLCodec::SetVideoBrightness(const int brightness)